@@ -15,19 +15,19 @@ without breaking any of your tools.
 """
 
 from .backend.plugin import (
-    Context, Instance, discover, Plugin,
+    Context, Instance, discover,
     Selector, Validator, Extractor, Conformer,
     plugin_paths, register_plugin_path,
     deregister_plugin_path, deregister_all,
     registered_paths, environment_paths, configured_paths)
 
-from .backend import config
-
+from . import Config
 from .backend.lib import log
 
 # For forwards-compatibility
 Integrator = Conformer
 
+config = Config()
 
 __all__ = [
     'Context',
@@ -49,5 +49,6 @@ __all__ = [
     'deregister_all',
 
     'config',
+
     'log'
 ]
