@@ -25,8 +25,10 @@ import inspect
 import traceback
 
 # Local library
+import pyblish
 import pyblish.backend.lib
-import pyblish.backend.config
+
+config = pyblish.Config()
 
 
 __all__ = ['Plugin',
@@ -46,10 +48,10 @@ __all__ = ['Plugin',
            'deregister_all']
 
 patterns = {
-    'validators': pyblish.backend.config.validators_regex,
-    'extractors': pyblish.backend.config.extractors_regex,
-    'selectors': pyblish.backend.config.selectors_regex,
-    'conformers': pyblish.backend.config.conformers_regex
+    'validators': config['validators_regex'],
+    'extractors': config['extractors_regex'],
+    'selectors': config['selectors_regex'],
+    'conformers': config['conformers_regex']
 }
 
 _registered_paths = list()
@@ -226,16 +228,16 @@ class Extractor(Plugin):
         assert date
         assert workspace_dir
 
-        # Commit directory based on template, see config.json
+        # Commit directory based on template, see config.yaml
         variables = {'pyblish': pyblish.backend.lib.main_package_path(),
-                     'prefix': pyblish.backend.config.prefix,
+                     'prefix': config['prefix'],
                      'date': date,
                      'family': instance.data('family'),
                      'instance': instance.data('name'),
                      'user': instance.data('user')}
 
         # Restore separators to those native to the current OS
-        commit_template = pyblish.backend.config.commit_template
+        commit_template = config['commit_template']
         commit_template = commit_template.replace('/', os.sep)
 
         commit_dir = commit_template.format(**variables)
@@ -350,7 +352,19 @@ class AbstractEntity(list):
 
 
 class Context(AbstractEntity):
-    """Maintain a collection of Instances"""
+    """Maintain a collection of Instances
+
+    .. note:: Context is a singleton.
+
+    """
+
+    _instance = None
+
+    def __new__(cls, *args, **kwargs):
+        if cls._instance is None:
+            cls._instance = super(Context, cls).__new__(
+                cls, *args, **kwargs)
+        return cls._instance
 
     def create_instance(self, name):
         """Convenience method of the following.
@@ -532,7 +546,7 @@ def configured_paths():
     """Return paths added via configuration"""
     paths = list()
 
-    for path_template in pyblish.backend.config.paths:
+    for path_template in config['paths']:
         variables = {'pyblish': pyblish.backend.lib.main_package_path()}
 
         plugin_path = path_template.format(**variables)
@@ -551,7 +565,7 @@ def environment_paths():
 
     paths = list()
 
-    env_var = pyblish.backend.config.paths_environment_variable
+    env_var = config['paths_environment_variable']
     env_val = os.environ.get(env_var)
     if env_val:
         sep = ';' if os.name == 'nt' else ':'
@@ -760,9 +774,9 @@ def _discover_type(type, paths, regex=None):
                 module = pyblish.backend.lib.import_module(mod_name)
                 reload(module)
 
-            except (ImportError, IndentationError) as e:
+            except Exception as err:
                 log.warning('Module: "{mod}" skipped ({msg})'.format(
-                    mod=mod_name, msg=e))
+                    mod=mod_name, msg=err))
                 continue
 
             finally:
